/**
 This file is software from the ORKWAN project.
 http://www.orkwan.com
 
 Copyright (C) 2000-2008 Henrik Nyberg.
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "ORKWAN" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact <info_AT_orkwan_DOT_com>.

 4. Products derived from this software may not be called "ORKWAN", nor
    may "ORKWAN" appear in their name, without prior written permission
    from the ORKWAN Project <info_AT_orkwan_DOT_com>.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by the
      ORKWAN Project (http://www.orkwan.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 */

package com.orkwan;

/**
 * This class is used for storing runtime metrics data for an OrkwanController.
 *
 * @author Henrik Nyberg
 */
public class OrkwanControllerMetric
{
    /** Class name of OrkwanController */
	private String name;
	
    /** load counters */	
	private int countLoadByUri;
	private int countLoadByParameter;
	
    /** execute counter (after successful execution) */	
	private int countExecute;
	
    /** total execution time in ms for all controllers of this class */	
	private long timeExecute;
	
    /** error counter */	
	private int countError;
	
    /** last error (throwable) */
	private Throwable lastError;
	
	/**
	 * Constructor
	 */
	public OrkwanControllerMetric(String name)
	{
		this.name = name;
	}
	
	/**
	 * Increment load counter
	 */
	public void load(boolean byUri)
	{
		if (byUri)
		{
			countLoadByUri++;
		}
		else
		{
			countLoadByParameter++;
		}
	}
	
	/**
	 * Increment execute counter and execute time
	 */
	public void execute(long executeTime)
	{
		countExecute++;
		timeExecute += executeTime;
	}
	
	/**
	 * Get average execute time (ms)
	 */
	public long getAverageExecuteTime()
	{
		return Math.round(timeExecute / (double) countExecute);
	}
	
	/**
	 * Increment error counter
	 * 
	 * @param t The error throwable
	 */
	public void error(Throwable t)
	{
		countError++;
		lastError = t;
	}

	/**
	 * Get the error count
	 * 
	 * @return the countError
	 */
	public int getCountError()
	{
		return countError;
	}

	/**
	 * Get the last error
	 * 
	 * @return throwable The last error throwable
	 */
	public Throwable getLastError()
	{
		return lastError;
	}

	/**
	 * Get the executions count
	 * 
	 * @return the countExecute
	 */
	public int getCountExecute()
	{
		return countExecute;
	}

	/**
	 * Get the load by url parameter count
	 * 
	 * @return the countLoadByParameter
	 */
	public int getCountLoadByParameter()
	{
		return countLoadByParameter;
	}

	/**
	 * Get the load by uri count
	 * 
	 * @return the countLoadByUri
	 */
	public int getCountLoadByUri()
	{
		return countLoadByUri;
	}

	/**
	 * Get the name
	 * 
	 * @return the name
	 */
	public String getName()
	{
		return name;
	}

	/**
	 * Get the time executed
	 * 
	 * @return the timeExecute
	 */
	public long getTimeExecute()
	{
		return timeExecute;
	}
	

}
