/**
 This file is software from the ORKWAN project.
 http://www.orkwan.com
 
 Copyright (C) 2000-2008 Henrik Nyberg.
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "ORKWAN" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact <info_AT_orkwan_DOT_com>.

 4. Products derived from this software may not be called "ORKWAN", nor
    may "ORKWAN" appear in their name, without prior written permission
    from the ORKWAN Project <info_AT_orkwan_DOT_com>.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by the
      ORKWAN Project (http://www.orkwan.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 */

package com.orkwan;

/**
 * This class provides native orkwan logging to standard out.
 *
 * @author Henrik Nyberg
 */

public class OrkwanLogger
{
	/**
	 * log info without source reference
	 * 
	 * @param s The info comment to log
	 */
	public static void info(String s)
	{
		System.out.println(s);	
	}
	
	/**
	 * log info for specified object
	 * 
	 * @param object The object to log info for
	 * @param s The info comment to log
	 */
	public static void info(Object object, String s)
	{
		System.out.println("{" + object.getClass().getName() + "} " + s);	
	}

	/**
	 * log error for specified object
	 * 
	 * @param object The object to log info for
	 * @param s The error comment to log
	 */
	public static void error(Object object, String s)
	{
		System.out.println("[" + object.getClass().getName() + "] " + s);	
	}
	
	/**
	 * log error and strack trace
	 * 
	 * @param object The object to log info for
	 * @param s The error comment to log
	 * @param t The error throwable
	 */
	public static void error(Object object, String s, Throwable t)
	{
		System.out.println("[" + object.getClass().getName() + "] " + s + ", error = " + t);
		t.printStackTrace(System.out);
	}
}
