/**
 This file is software from the ORKWAN project.
 http://www.orkwan.com
 
 Copyright (C) 2000-2008 Henrik Nyberg.
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions
 are met:

 1. Redistributions of source code must retain the above copyright
    notice, this list of conditions, and the following disclaimer.

 2. Redistributions in binary form must reproduce the above copyright
    notice, this list of conditions, and the disclaimer that follows
    these conditions in the documentation and/or other materials
    provided with the distribution.

 3. The name "ORKWAN" must not be used to endorse or promote products
    derived from this software without prior written permission.  For
    written permission, please contact <info_AT_orkwan_DOT_com>.

 4. Products derived from this software may not be called "ORKWAN", nor
    may "ORKWAN" appear in their name, without prior written permission
    from the ORKWAN Project <info_AT_orkwan_DOT_com>.

 In addition, we request (but do not require) that you include in the
 end-user documentation provided with the redistribution and/or in the
 software itself an acknowledgement equivalent to the following:
     "This product includes software developed by the
      ORKWAN Project (http://www.orkwan.com/)."

 THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS OR THE PROJECT
 CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 SUCH DAMAGE.
 */

package com.orkwan;

import org.jdom.Document;
import org.jdom.input.SAXBuilder;
import org.jdom.output.Format;
import org.jdom.output.XMLOutputter;

import java.io.StringReader;

/**
 * Utility class for parsing and outputting XML based on JDOM. The Xerces parser included
 * in the JDK (Java 5 and up) is used for parsing xml.
 * 
 * @author Henrik Nyberg
 */
public class XMLFactory {

    /** SAX Parser */
    private static SAXBuilder PARSER;
    
    /** SAX Parser class (included in Java 5 and up) */
    private static final String PARSER_CLASS = "com.sun.org.apache.xerces.internal.parsers.SAXParser";

    static
    {
        // initialize parser
        PARSER = new SAXBuilder(PARSER_CLASS);
    }

    /**
     * String to document.
     *
     * @param xml The xml string to parse to a Document.
     * @return The parsed xml string as a jdom Document.
    */
    public static Document string2document(String xml) throws Exception
    {
        return PARSER.build(new StringReader(xml));
    }

    /**
     * Document to string without specifying encoding (default is utf-8).
     *
     * @param xml The xml document to "stringify".
     * @return The xml document as a string.
    */
    public static String document2string(Document xml)
    {
        return document2string(xml, false, null);
    }

    /**
     * Document to string with specified encoding.
     *
     * @param xml The xml document.
     * @param encoding The encoding to use.
     * @return The xml document as a string.
    */
    public static String document2string(Document xml, String encoding)
    {
        return document2string(xml, false, encoding);
    }

    /**
     * Document to string, include top xml declaration or not. Will use default encoding.
     *
     * @param xml The xml document.
     * @param includeXmlDeclaration True if top xml declaration should be included, false if not.
     * @return The xml document as a string.
    */
    public static String document2string(Document xml, boolean includeXmlDeclaration)
    {
        return document2string(xml, includeXmlDeclaration, null);
    }

    /**
     * Document to string
     *
     * @param xml The xml document.
     * @param includeXmlDeclaration True if top xml declaration should be included, false if not.
     * @param encoding The encoding to use.
     * @return The xml document as a string.
    */
    public static String document2string(Document xml, boolean includeXmlDeclaration, String encoding)
    {
        Format format = Format.getPrettyFormat();
        format.setOmitDeclaration(!includeXmlDeclaration);
        if (encoding != null)
        {
            format.setEncoding(encoding);
        }

        XMLOutputter outputter = new XMLOutputter();
        outputter.setFormat(format);

        return filter(outputter.outputString(xml));
    }

    /**
     * Method to filter characters from JDOM xml outputter
     * 
     * @param xml The xml
     * @return The xml after filter
     */
    private static String filter(String xml) 
    {
    	// reverse JDOM conversion of &#
        return xml.replaceAll("&amp;#", "&#");
    }
}